==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/bedget/vo/QuotasummaryVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordquotasummaryVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.QuotasummarydetailVO;
import com.ejianc.business.bedget.vo.SubpackagedetailVO;

/**
 * 限额设计汇总
 * 
 * @author generator
 * 
 */
public class QuotasummaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.math.BigDecimal costTotal; // 造价合计
    private java.math.BigDecimal partialItemTotal; // 分部分项合计
    private java.math.BigDecimal otherItemsTotal; // 其他项目合计
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.math.BigDecimal measuresItemTotal; // 措施项目合计
    
    private List<QuotasummarydetailVO> quotasummarydetailEntities = new ArrayList<>(); // 限额设计汇总子表
    private List<RecordquotasummaryVO> recordquotasummaryList = new ArrayList<>(); // 历史信

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getPartialItemTotal() {
        return partialItemTotal;
    }

    /**
     * 分部分项合计
     */
    public void setPartialItemTotal(java.math.BigDecimal partialItemTotal) {
        this.partialItemTotal = partialItemTotal;
    }
    /**
     * 其他项目合计
     */
    public java.math.BigDecimal getOtherItemsTotal() {
        return otherItemsTotal;
    }

    /**
     * 其他项目合计
     */
    public void setOtherItemsTotal(java.math.BigDecimal otherItemsTotal) {
        this.otherItemsTotal = otherItemsTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasuresItemTotal() {
        return measuresItemTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasuresItemTotal(java.math.BigDecimal measuresItemTotal) {
        this.measuresItemTotal = measuresItemTotal;
    }
    
     /**
      * 限额设计汇总子表
      */
     public List<QuotasummarydetailVO> getQuotasummarydetailEntities() {
        return quotasummarydetailEntities;
     }

     /**
      * 限额设计汇总子表
      */
     public void setQuotasummarydetailEntities(List<QuotasummarydetailVO> quotasummarydetailEntities) {
        this.quotasummarydetailEntities = quotasummarydetailEntities;
     }

    public List<RecordquotasummaryVO> getRecordquotasummaryList() {
        return recordquotasummaryList;
    }

    public void setRecordquotasummaryList(List<RecordquotasummaryVO> recordquotasummaryList) {
        this.recordquotasummaryList = recordquotasummaryList;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/bedget/vo/QuotasummaryVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordquotasummaryVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.QuotasummarydetailVO;
import com.ejianc.business.bedget.vo.SubpackagedetailVO;

/**
 * 限额设计汇总
 * 
 * @author generator
 * 
 */
public class QuotasummaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.math.BigDecimal costTotal; // 造价合计
    private java.math.BigDecimal partialItemTotal; // 分部分项合计
    private java.math.BigDecimal otherItemsTotal; // 其他项目合计
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.math.BigDecimal measuresItemTotal; // 措施项目合计

    private java.lang.String sort;
    private java.lang.String createTimeShow;
    private java.lang.String billStateStr;
    
    private List<QuotasummarydetailVO> quotasummarydetailEntities = new ArrayList<>(); // 限额设计汇总子表
    private List<RecordquotasummaryVO> recordquotasummaryList = new ArrayList<>(); // 历史信

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getPartialItemTotal() {
        return partialItemTotal;
    }

    /**
     * 分部分项合计
     */
    public void setPartialItemTotal(java.math.BigDecimal partialItemTotal) {
        this.partialItemTotal = partialItemTotal;
    }
    /**
     * 其他项目合计
     */
    public java.math.BigDecimal getOtherItemsTotal() {
        return otherItemsTotal;
    }

    /**
     * 其他项目合计
     */
    public void setOtherItemsTotal(java.math.BigDecimal otherItemsTotal) {
        this.otherItemsTotal = otherItemsTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasuresItemTotal() {
        return measuresItemTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasuresItemTotal(java.math.BigDecimal measuresItemTotal) {
        this.measuresItemTotal = measuresItemTotal;
    }
    
     /**
      * 限额设计汇总子表
      */
     public List<QuotasummarydetailVO> getQuotasummarydetailEntities() {
        return quotasummarydetailEntities;
     }

     /**
      * 限额设计汇总子表
      */
     public void setQuotasummarydetailEntities(List<QuotasummarydetailVO> quotasummarydetailEntities) {
        this.quotasummarydetailEntities = quotasummarydetailEntities;
     }

    public List<RecordquotasummaryVO> getRecordquotasummaryList() {
        return recordquotasummaryList;
    }

    public void setRecordquotasummaryList(List<RecordquotasummaryVO> recordquotasummaryList) {
        this.recordquotasummaryList = recordquotasummaryList;
    }
}
